# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .public_asset_out import PublicAssetOut


class PaginatedAssetsOut(UniversalBaseModel):
    """
    Paginated response containing a list of assets with pagination metadata.
    """

    has_more: bool = pydantic.Field()
    """
    Whether there are more assets available beyond this page
    """

    items: typing.List[PublicAssetOut] = pydantic.Field()
    """
    Array of asset objects for the current page
    """

    limit: int = pydantic.Field()
    """
    Maximum number of assets returned in this response (1-500)
    """

    next_offset: typing.Optional[int] = pydantic.Field(default=None)
    """
    Offset value to use for the next page request, null if no more pages
    """

    offset: int = pydantic.Field()
    """
    Number of assets skipped from the beginning of the result set
    """

    total: int = pydantic.Field()
    """
    Total number of assets matching the query filters
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .conversation_asset_info import ConversationAssetInfo


class ThreadStatusResponseOut(UniversalBaseModel):
    """
    Response model for thread status check.
    """

    conversation_asset: typing.Optional[ConversationAssetInfo] = pydantic.Field(default=None)
    """
    Information about the associated conversation asset
    """

    created_at: str = pydantic.Field()
    """
    ISO timestamp when thread was created
    """

    error: typing.Optional[str] = pydantic.Field(default=None)
    """
    Error message if thread execution failed
    """

    status: str = pydantic.Field()
    """
    Current status of the thread (e.g., 'running', 'completed', 'failed')
    """

    thread_id: str = pydantic.Field()
    """
    The thread ID that was checked
    """

    updated_at: str = pydantic.Field()
    """
    ISO timestamp when thread was last updated
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .thread_batch_stop_result_item import ThreadBatchStopResultItem


class ThreadBatchStopResponseOut(UniversalBaseModel):
    """
    Response model for batch thread stop.
    """

    failed_count: int = pydantic.Field()
    """
    Number of threads that failed to stop
    """

    results: typing.List[ThreadBatchStopResultItem] = pydantic.Field()
    """
    Detailed results for each thread
    """

    stopped_count: int = pydantic.Field()
    """
    Number of threads successfully stopped
    """

    total_requested: int = pydantic.Field()
    """
    Total number of threads requested to stop
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
